==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/AWSLoadBalancerParametersFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AWSLoadBalancerParametersFluent<A extends io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildClassicLoadBalancer instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters getClassicLoadBalancer();
  public io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters buildClassicLoadBalancer();
  public A withClassicLoadBalancer(io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters classicLoadBalancer);
  public java.lang.Boolean hasClassicLoadBalancer();
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<A> withNewClassicLoadBalancer();
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<A> withNewClassicLoadBalancerLike(io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters item);
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<A> editClassicLoadBalancer();
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<A> editOrNewClassicLoadBalancer();
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<A> editOrNewClassicLoadBalancerLike(io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters item);
  
  /**
   * This method has been deprecated, please use method buildNetworkLoadBalancer instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters getNetworkLoadBalancer();
  public io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters buildNetworkLoadBalancer();
  public A withNetworkLoadBalancer(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters networkLoadBalancer);
  public java.lang.Boolean hasNetworkLoadBalancer();
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<A> withNewNetworkLoadBalancer();
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<A> withNewNetworkLoadBalancerLike(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters item);
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<A> editNetworkLoadBalancer();
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<A> editOrNewNetworkLoadBalancer();
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<A> editOrNewNetworkLoadBalancerLike(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters item);
  public java.lang.String getType();
  public A withType(java.lang.String type);
  public java.lang.Boolean hasType();
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0);
  public interface ClassicLoadBalancerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParametersFluent<io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<N>>{
    public N and();
    public N endClassicLoadBalancer();
    
  }
  public interface NetworkLoadBalancerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersFluent<io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<N>>{
    public N and();
    public N endNetworkLoadBalancer();
    
  }
  
}

==> openshift-model-operator-5.12.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/AWSLoadBalancerParametersFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AWSLoadBalancerParametersFluent<A extends io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildClassicLoadBalancer instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters getClassicLoadBalancer();
  public io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters buildClassicLoadBalancer();
  public A withClassicLoadBalancer(io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters classicLoadBalancer);
  public java.lang.Boolean hasClassicLoadBalancer();
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<A> withNewClassicLoadBalancer();
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<A> withNewClassicLoadBalancerLike(io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters item);
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<A> editClassicLoadBalancer();
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<A> editOrNewClassicLoadBalancer();
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<A> editOrNewClassicLoadBalancerLike(io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParameters item);
  
  /**
   * This method has been deprecated, please use method buildNetworkLoadBalancer instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters getNetworkLoadBalancer();
  public io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters buildNetworkLoadBalancer();
  public A withNetworkLoadBalancer(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters networkLoadBalancer);
  public java.lang.Boolean hasNetworkLoadBalancer();
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<A> withNewNetworkLoadBalancer();
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<A> withNewNetworkLoadBalancerLike(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters item);
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<A> editNetworkLoadBalancer();
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<A> editOrNewNetworkLoadBalancer();
  public io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<A> editOrNewNetworkLoadBalancerLike(io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParameters item);
  public java.lang.String getType();
  public A withType(java.lang.String type);
  public java.lang.Boolean hasType();
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ClassicLoadBalancerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.AWSClassicLoadBalancerParametersFluent<io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.ClassicLoadBalancerNested<N>>{
    public N and();
    public N endClassicLoadBalancer();
    
  }
  public interface NetworkLoadBalancerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.AWSNetworkLoadBalancerParametersFluent<io.fabric8.openshift.api.model.operator.v1.AWSLoadBalancerParametersFluent.NetworkLoadBalancerNested<N>>{
    public N and();
    public N endNetworkLoadBalancer();
    
  }
  
}
